@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "shift-number" "0.1"
+(define-package "shift-number" "20250917.433"
   "Increase/decrease the number at point."
-  ()
-  :url "https://github.com/alezost/shift-number.el"
-  :commit "ba3c1f2e6b01bf14aa1433c2a49098af1c025f7c"
-  :revdesc "ba3c1f2e6b01"
+  '((emacs "24.1"))
+  :url "https://codeberg.org/ideasman42/emacs-shift-number"
+  :commit "058fa307293287e9232219007893cb56abb2c4b3"
+  :revdesc "058fa3072932"
   :keywords '("convenience")
   :authors '(("Alex Kost" . "alezost@gmail.com"))
   :maintainers '(("Alex Kost" . "alezost@gmail.com")))
